Roles
GET/v1/rolesGET /v1/roles
Code samples
cURL
# You can also use wget
curl -X GET /v1/roles \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
GET /v1/roles
Retrieves roles based on the provided request.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| select | query | string | false | none |
| filter | query | string | false | none |
| sort | query | string | false | none |
| take | query | integer(int32) | false | none |
| skip | query | integer(int32) | false | none |
Example responses
200 Response
{"success":true,"code":0,"message":"string","roles":[{"id":"string","name":"string","description":"string"}],"totalRolesCount":0}{
"success": true,
"code": 0,
"message": "string",
"roles": [
{
"id": "string",
"name": "string",
"description": "string"
}
],
"totalRolesCount": 0
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.GetRolesResponse |
Authentication: API key (x-api-key).
GET/v1/users/{userId}/rolesGET /v1/users/{userId}/roles
Code samples
cURL
# You can also use wget
curl -X GET /v1/users/{userId}/roles \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
GET /v1/users/\{userId\}/roles
Retrieves the roles of a specific user based on the provided request.
Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The user ID. |
| select | query | string | false | none |
| filter | query | string | false | none |
| sort | query | string | false | none |
| take | query | integer(int32) | false | none |
| skip | query | integer(int32) | false | none |
Example responses
200 Response
{"success":true,"code":0,"message":"string","roles":[{"id":"string","name":"string","description":"string"}],"totalRolesCount":0}{
"success": true,
"code": 0,
"message": "string",
"roles": [
{
"id": "string",
"name": "string",
"description": "string"
}
],
"totalRolesCount": 0
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.GetUserRolesResponse |
Authentication: API key (x-api-key).
POST/v1/users/{userId}/rolesPOST /v1/users/{userId}/roles
Code samples
cURL
# You can also use wget
curl -X POST /v1/users/{userId}/roles \
-H 'Content-Type: application/json-patch+json' \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
POST /v1/users/\{userId\}/roles
Adds a user to the specified roles.
Body parameter
{
"roles": "string"
}Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The user ID. |
| body | body | Management.AddUserToRoleRequest | false | The request containing the user ID and the roles to add. |
Example responses
200 Response
{"success":true,"code":0,"message":"string"}{
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.AddUserToRoleResponse |
Authentication: API key (x-api-key).
DELETE/v1/users/{userId}/rolesDELETE /v1/users/{userId}/roles
Code samples
cURL
# You can also use wget
curl -X DELETE /v1/users/{userId}/roles \
-H 'Content-Type: application/json-patch+json' \
-H 'Accept: text/plain' \
-H 'x-api-key: API_KEY'
DELETE /v1/users/\{userId\}/roles
Removes a user from the specified roles.
Body parameter
{
"roles": "string"
}Parameters
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| userId | path | string | true | The user ID. |
| body | body | Management.RemoveUserFromRoleRequest | false | The request containing the user ID and the roles to remove. |
Example responses
200 Response
{"success":true,"code":0,"message":"string"}{
"success": true,
"code": 0,
"message": "string"
}Responses
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Management.RemoveUserFromRoleResponse |
Authentication: API key (x-api-key).
Last updated on